<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" version="2.0">
  <channel>
    <title>topic Optimizer hangs on non-terminating while loop in OpenCL* for CPU</title>
    <link>https://community.intel.com/t5/OpenCL-for-CPU/Optimizer-hangs-on-non-terminating-while-loop/m-p/1170689#M6529</link>
    <description>&lt;P&gt;Compilation of the following kernel loops indefinitely:&lt;/P&gt;

&lt;PRE class="brush:cpp;"&gt;kernel void A() {
  int a = get_global_id(0);
  while (a &amp;lt; 512) {}
}&lt;/PRE&gt;

&lt;P&gt;Passing argument -cl-opt-disable to&amp;nbsp;clBuildProgram() prevents this.&lt;/P&gt;

&lt;P&gt;Reproduced on:&lt;/P&gt;

&lt;UL&gt;
	&lt;LI&gt;/opt/intel/opencl-1.2-6.4.0.25/lib64/libintelocl.so&lt;/LI&gt;
	&lt;LI&gt;&lt;SPAN style="font-size: 1em;"&gt;/opt/intel/opencl-1.2-4.4.0.117/lib64/libintelocl.so&lt;/SPAN&gt;&lt;/LI&gt;
&lt;/UL&gt;

&lt;P&gt;&amp;nbsp;&lt;/P&gt;</description>
    <pubDate>Mon, 21 Aug 2017 20:28:18 GMT</pubDate>
    <dc:creator>Chris_C_1</dc:creator>
    <dc:date>2017-08-21T20:28:18Z</dc:date>
    <item>
      <title>Optimizer hangs on non-terminating while loop</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Optimizer-hangs-on-non-terminating-while-loop/m-p/1170689#M6529</link>
      <description>&lt;P&gt;Compilation of the following kernel loops indefinitely:&lt;/P&gt;

&lt;PRE class="brush:cpp;"&gt;kernel void A() {
  int a = get_global_id(0);
  while (a &amp;lt; 512) {}
}&lt;/PRE&gt;

&lt;P&gt;Passing argument -cl-opt-disable to&amp;nbsp;clBuildProgram() prevents this.&lt;/P&gt;

&lt;P&gt;Reproduced on:&lt;/P&gt;

&lt;UL&gt;
	&lt;LI&gt;/opt/intel/opencl-1.2-6.4.0.25/lib64/libintelocl.so&lt;/LI&gt;
	&lt;LI&gt;&lt;SPAN style="font-size: 1em;"&gt;/opt/intel/opencl-1.2-4.4.0.117/lib64/libintelocl.so&lt;/SPAN&gt;&lt;/LI&gt;
&lt;/UL&gt;

&lt;P&gt;&amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Mon, 21 Aug 2017 20:28:18 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Optimizer-hangs-on-non-terminating-while-loop/m-p/1170689#M6529</guid>
      <dc:creator>Chris_C_1</dc:creator>
      <dc:date>2017-08-21T20:28:18Z</dc:date>
    </item>
  </channel>
</rss>

